==> chrome-devtools-kotlin-0.13.1-sources.jar: org/hildan/chrome/devtools/domains/fetch/events/FetchEvents.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.fetch.events

import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.domains.fetch.AuthChallenge
import org.hildan.chrome.devtools.domains.fetch.HeaderEntry
import org.hildan.chrome.devtools.domains.fetch.RequestId
import org.hildan.chrome.devtools.domains.network.ErrorReason
import org.hildan.chrome.devtools.domains.network.Request
import org.hildan.chrome.devtools.domains.network.ResourceType
import org.hildan.chrome.devtools.domains.page.FrameId

@Serializable
public sealed class FetchEvent {
  /**
   * Issued when the domain is enabled and the request URL matches the
   * specified filter. The request is paused until the client responds
   * with one of continueRequest, failRequest or fulfillRequest.
   * The stage of the request can be determined by presence of responseErrorReason
   * and responseStatusCode -- the request is at the response stage if either
   * of these fields is present and in the request stage otherwise.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Fetch/#event-requestPaused)
   */
  @Serializable
  public data class RequestPausedEvent(
    /**
     * Each request the page makes will have a unique id.
     */
    public val requestId: RequestId,
    /**
     * The details of the request.
     */
    public val request: Request,
    /**
     * The id of the frame that initiated the request.
     */
    public val frameId: FrameId,
    /**
     * How the requested resource will be used.
     */
    public val resourceType: ResourceType,
    /**
     * Response error if intercepted at response stage.
     */
    public val responseErrorReason: ErrorReason? = null,
    /**
     * Response code if intercepted at response stage.
     */
    public val responseStatusCode: Int? = null,
    /**
     * Response headers if intercepted at the response stage.
     */
    public val responseHeaders: List<HeaderEntry>? = null,
    /**
     * If the intercepted request had a corresponding Network.requestWillBeSent event fired for it,
     * then this networkId will be the same as the requestId present in the requestWillBeSent event.
     */
    public val networkId: RequestId? = null
  ) : FetchEvent()

  /**
   * Issued when the domain is enabled with handleAuthRequests set to true.
   * The request is paused until client responds with continueWithAuth.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Fetch/#event-authRequired)
   */
  @Serializable
  public data class AuthRequiredEvent(
    /**
     * Each request the page makes will have a unique id.
     */
    public val requestId: RequestId,
    /**
     * The details of the request.
     */
    public val request: Request,
    /**
     * The id of the frame that initiated the request.
     */
    public val frameId: FrameId,
    /**
     * How the requested resource will be used.
     */
    public val resourceType: ResourceType,
    /**
     * Details of the Authorization Challenge encountered.
     * If this is set, client should respond with continueRequest that
     * contains AuthChallengeResponse.
     */
    public val authChallenge: AuthChallenge
  ) : FetchEvent()
}

==> chrome-devtools-kotlin-4.2.0-sources.jar: org/hildan/chrome/devtools/domains/fetch/events/FetchEvents.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.fetch.events

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.domains.fetch.AuthChallenge
import org.hildan.chrome.devtools.domains.fetch.HeaderEntry
import org.hildan.chrome.devtools.domains.fetch.RequestId
import org.hildan.chrome.devtools.domains.network.ErrorReason
import org.hildan.chrome.devtools.domains.network.Request
import org.hildan.chrome.devtools.domains.network.ResourceType
import org.hildan.chrome.devtools.domains.page.FrameId
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

@Serializable
public sealed class FetchEvent {
  /**
   * Issued when the domain is enabled and the request URL matches the
   * specified filter. The request is paused until the client responds
   * with one of continueRequest, failRequest or fulfillRequest.
   * The stage of the request can be determined by presence of responseErrorReason
   * and responseStatusCode -- the request is at the response stage if either
   * of these fields is present and in the request stage otherwise.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Fetch/#event-requestPaused)
   */
  @Serializable
  public data class RequestPaused(
    /**
     * Each request the page makes will have a unique id.
     */
    public val requestId: RequestId,
    /**
     * The details of the request.
     */
    public val request: Request,
    /**
     * The id of the frame that initiated the request.
     */
    public val frameId: FrameId,
    /**
     * How the requested resource will be used.
     */
    public val resourceType: ResourceType,
    /**
     * Response error if intercepted at response stage.
     */
    public val responseErrorReason: ErrorReason? = null,
    /**
     * Response code if intercepted at response stage.
     */
    public val responseStatusCode: Int? = null,
    /**
     * Response status text if intercepted at response stage.
     */
    public val responseStatusText: String? = null,
    /**
     * Response headers if intercepted at the response stage.
     */
    public val responseHeaders: List<HeaderEntry>? = null,
    /**
     * If the intercepted request had a corresponding Network.requestWillBeSent event fired for it,
     * then this networkId will be the same as the requestId present in the requestWillBeSent event.
     */
    public val networkId: org.hildan.chrome.devtools.domains.network.RequestId? = null,
    /**
     * If the request is due to a redirect response from the server, the id of the request that
     * has caused the redirect.
     */
    @ExperimentalChromeApi
    public val redirectedRequestId: RequestId? = null,
  ) : FetchEvent()

  /**
   * Issued when the domain is enabled with handleAuthRequests set to true.
   * The request is paused until client responds with continueWithAuth.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Fetch/#event-authRequired)
   */
  @Serializable
  public data class AuthRequired(
    /**
     * Each request the page makes will have a unique id.
     */
    public val requestId: RequestId,
    /**
     * The details of the request.
     */
    public val request: Request,
    /**
     * The id of the frame that initiated the request.
     */
    public val frameId: FrameId,
    /**
     * How the requested resource will be used.
     */
    public val resourceType: ResourceType,
    /**
     * Details of the Authorization Challenge encountered.
     * If this is set, client should respond with continueRequest that
     * contains AuthChallengeResponse.
     */
    public val authChallenge: AuthChallenge,
  ) : FetchEvent()
}
